==> gwydion-dylan_2.3.12pre3.orig.tar.gz: gwydion-dylan-2.3.12pre3/d2c/compiler/Macintosh/GwydionVersion.h <==
// File: GwydionVersion.h
// RCS-header: $Header: /var/lib/cvs/src/d2c/compiler/Macintosh/GwydionVersion.h,v 1.4 2002/06/14 13:55:04 gabor Exp $
// Purpose: list necessary #defines for .r (and .cpp)  files
// Author: Gabor Greif <gabor@mac.com>

//======================================================================
//
// Copyright (c) 2000, 2001, 2002  Gwydion Dylan Maintainers
// All rights reserved.
// 
// Use and copying of this software and preparation of derivative
// works based on this software are permitted, including commercial
// use, provided that the following conditions are observed:
// 
// 1. This copyright notice must be retained in full on any copies
//    and on appropriate parts of any derivative works.
// 2. Documentation (paper or online) accompanying any system that
//    incorporates this software, or any part of it, must acknowledge
//    the contribution of the Gwydion Project at Carnegie Mellon
//    University, and the Gwydion Dylan Maintainers.
// 
// This software is made available "as is".  Neither the authors nor
// Carnegie Mellon University make any warranty about the software,
// its performance, or its conformity to any specification.
// 
// Bug reports should be sent to <gd-bugs@gwydiondylan.org>; questions,
// comments and suggestions are welcome at <gd-hackers@gwydiondylan.org>.
// Also, see http://www.gwydiondylan.org/ for updates and documentation. 
//
//======================================================================


#define DevelopmentState "b3pre2"
#define DevelopmentStage beta
#define DevelopmentVersion 3

#define CodebaseVersion "2.3.9"
#define CodebaseMajor 2
#define CodebaseMinor 0x39

#define CopyrightYears "2000-2002"

==> gwydion-dylan-2.4.0.tar.gz: gwydion-dylan-2.4.0/d2c/compiler/Macintosh/GwydionVersion.h <==
// File: GwydionVersion.h
// RCS-header: $Header: /scm/cvs/src/d2c/compiler/Macintosh/GwydionVersion.h,v 1.6.2.1 2004/10/09 07:00:53 gabor Exp $
// Purpose: list necessary #defines for .r (and .cpp)  files
// Author: Gabor Greif <gabor@mac.com>

//======================================================================
//
// Copyright (c) 2000 - 2004  Gwydion Dylan Maintainers
// All rights reserved.
// 
// Use and copying of this software and preparation of derivative
// works based on this software are permitted, including commercial
// use, provided that the following conditions are observed:
// 
// 1. This copyright notice must be retained in full on any copies
//    and on appropriate parts of any derivative works.
// 2. Documentation (paper or online) accompanying any system that
//    incorporates this software, or any part of it, must acknowledge
//    the contribution of the Gwydion Project at Carnegie Mellon
//    University, and the Gwydion Dylan Maintainers.
// 
// This software is made available "as is".  Neither the authors nor
// Carnegie Mellon University make any warranty about the software,
// its performance, or its conformity to any specification.
// 
// Bug reports should be sent to <gd-bugs@gwydiondylan.org>; questions,
// comments and suggestions are welcome at <gd-hackers@gwydiondylan.org>.
// Also, see http://www.gwydiondylan.org/ for updates and documentation. 
//
//======================================================================


#define DevelopmentState "b5"
#define DevelopmentStage beta
#define DevelopmentVersion 5

#define CodebaseVersion "2.4.0"
#define CodebaseMajor 2
#define CodebaseMinor 0x40

#define CopyrightYears "2000-2004"
